@@ -1,4 +1,4 @@
-# Copyright 2011-2022, Paul Johnson (paul@pjcj.net)
+# Copyright 2011-2024, Paul Johnson (paul@pjcj.net)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -10,7 +10,7 @@ package Devel::Cover::DB::Digests;
 use strict;
 use warnings;
 
-our $VERSION = '1.39'; # VERSION
+our $VERSION = '1.42'; # VERSION
 
 use Devel::Cover::DB::Structure;
 use Devel::Cover::DB::IO;
@@ -18,66 +18,63 @@ use Devel::Cover::DB::IO;
 my $File = "digests";
 
 sub new {
-    my $class = shift;
-    my $self  = {
-        digests => {},
-        @_
-    };
+  my $class = shift;
+  my $self  = { digests => {}, @_ };
 
-    die "No db specified" unless $self->{db};
-    $self->{file} = "$self->{db}/$File";
+  die "No db specified" unless $self->{db};
+  $self->{file} = "$self->{db}/$File";
 
-    bless $self, $class;
-    $self->read;
-    $self
+  bless $self, $class;
+  $self->read;
+  $self
 }
 
 sub read {
-    my $self = shift;
-    my $io = Devel::Cover::DB::IO->new;
-    $self->{digests} = $io->read($self->{file}) if -e $self->{file};
-    $self
+  my $self = shift;
+  my $io   = Devel::Cover::DB::IO->new;
+  $self->{digests} = $io->read($self->{file}) if -e $self->{file};
+  $self
 }
 
 sub write {
-    my $self = shift;
-    my $io = Devel::Cover::DB::IO->new;
-    $io->write($self->{digests}, $self->{file});
-    $self
+  my $self = shift;
+  my $io   = Devel::Cover::DB::IO->new;
+  $io->write($self->{digests}, $self->{file});
+  $self
 }
 
 sub get {
-    my $self = shift;
-    my ($digest) = @_;
-    $self->{digests}{$digest}
+  my $self = shift;
+  my ($digest) = @_;
+  $self->{digests}{$digest}
 }
 
 sub set {
-    my $self = shift;
-    my ($file, $digest) = @_;
-    $self->{digests}{$digest} = $file;
+  my $self = shift;
+  my ($file, $digest) = @_;
+  $self->{digests}{$digest} = $file;
 }
 
 sub canonical_file {
-    my $self = shift;
-    my ($file) = @_;
+  my $self = shift;
+  my ($file) = @_;
 
-    my $cfile = $file;
-    my $digest = Devel::Cover::DB::Structure->digest($file);
-    if ($digest) {
-        my $dfile = $self->get($digest);
-        if ($dfile && $dfile ne $file) {
-            print STDERR "Devel::Cover: Adding coverage for $file to $dfile\n"
-                unless $Devel::Cover::Silent;
-            $cfile = $dfile;
-        } else {
-            $self->set($file, $digest);
-        }
+  my $cfile  = $file;
+  my $digest = Devel::Cover::DB::Structure->digest($file);
+  if ($digest) {
+    my $dfile = $self->get($digest);
+    if ($dfile && $dfile ne $file) {
+      print STDERR "Devel::Cover: Adding coverage for $file to $dfile\n"
+        unless $Devel::Cover::Silent;
+      $cfile = $dfile;
+    } else {
+      $self->set($file, $digest);
     }
+  }
 
-    # warn "[$file] => [$cfile]\n";
+  # warn "[$file] => [$cfile]\n";
 
-    $cfile
+  $cfile
 }
 
 1
@@ -90,7 +87,7 @@ Devel::Cover::DB::Digests - store digests for Devel::Cover::DB
 
 =head1 VERSION
 
-version 1.39
+version 1.42
 
 =head1 SYNOPSIS
 
@@ -134,7 +131,7 @@ Huh?
 
 =head1 LICENCE
 
-Copyright 2011-2022, Paul Johnson (paul@pjcj.net)
+Copyright 2011-2024, Paul Johnson (paul@pjcj.net)
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
