@@ -1,4 +1,4 @@
-# Copyright 2001-2022, Paul Johnson (paul@pjcj.net)
+# Copyright 2001-2024, Paul Johnson (paul@pjcj.net)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -10,31 +10,30 @@ package Devel::Cover::Pod;
 use strict;
 use warnings;
 
-our $VERSION = '1.39'; # VERSION
+our $VERSION = '1.42'; # VERSION
 
 use base "Devel::Cover::Criterion";
 
-BEGIN { eval "use Pod::Coverage 0.06" }     # We'll use this if it is available.
+BEGIN { eval "use Pod::Coverage 0.06" }  # We'll use this if it is available.
 
-sub uncoverable { $_[0][2]               }
-sub covered     { $_[0][0] ? 1 : 0       }
-sub total       { 1                      }
-sub percentage  { $_[0][0] ? 100 : 0     }
-sub error       { $_[0][0] xor !$_[0][2] }
-sub criterion   { "pod"                  }
+sub uncoverable { $_[0][2] }
+sub covered     { $_[0][0] ? 1 : 0 }
+sub total       { 1 }
+sub percentage  { $_[0][0] ? 100 : 0 }
+sub error       { $_[0]->simple_error }
+sub criterion   { "pod" }
 
 sub calculate_summary {
-    my $self = shift;
-    my ($db, $file) = @_;
+  my $self = shift;
+  my ($db, $file) = @_;
 
-    return unless $INC{"Pod/Coverage.pm"};
+  return unless $INC{"Pod/Coverage.pm"};
 
-    my $s = $db->{summary};
+  my $s = $db->{summary};
 
-    $self->aggregate($s, $file, 'total', $self->total);
-    $self->aggregate($s, $file, 'covered', 1)
-        if $self->covered;
-    $self->aggregate($s, $file, 'error', $self->error);
+  $self->aggregate($s, $file, 'total',   $self->total);
+  $self->aggregate($s, $file, 'covered', 1) if $self->covered;
+  $self->aggregate($s, $file, 'error',   $self->error);
 }
 
 1
@@ -47,7 +46,7 @@ Devel::Cover::Pod - Code coverage metrics for Perl
 
 =head1 VERSION
 
-version 1.39
+version 1.42
 
 =head1 SYNOPSIS
 
@@ -69,7 +68,7 @@ Huh?
 
 =head1 LICENCE
 
-Copyright 2001-2022, Paul Johnson (paul@pjcj.net)
+Copyright 2001-2024, Paul Johnson (paul@pjcj.net)
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
