@@ -1,4 +1,4 @@
-# Copyright 2004-2022, Paul Johnson (paul@pjcj.net)
+# Copyright 2004-2024, Paul Johnson (paul@pjcj.net)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -10,17 +10,17 @@ package Devel::Cover::Subroutine;
 use strict;
 use warnings;
 
-our $VERSION = '1.39'; # VERSION
+our $VERSION = '1.42'; # VERSION
 
 use base "Devel::Cover::Criterion";
 
-sub uncoverable { $_[0][2]               }
-sub covered     { $_[0][0]               }
-sub total       { 1                      }
-sub percentage  { $_[0][0] ? 100 : 0     }
-sub error       { $_[0][0] xor !$_[0][2] }
-sub name        { $_[0][1]               }
-sub criterion   { "subroutine"           }
+sub uncoverable { $_[0][2] }
+sub covered     { $_[0][0] }
+sub total       { 1 }
+sub percentage  { $_[0][0] ? 100 : 0 }
+sub error       { $_[0]->simple_error }
+sub name        { $_[0][1] }
+sub criterion   { "subroutine" }
 
 1
 
@@ -32,7 +32,7 @@ Devel::Cover::Subroutine - Code coverage metrics for Perl subroutines
 
 =head1 VERSION
 
-version 1.39
+version 1.42
 
 =head1 SYNOPSIS
 
@@ -54,7 +54,7 @@ Huh?
 
 =head1 LICENCE
 
-Copyright 2004-2022, Paul Johnson (paul@pjcj.net)
+Copyright 2004-2024, Paul Johnson (paul@pjcj.net)
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
