@@ -11,15 +11,14 @@ use warnings;
 # Notes      :
 #-------------------------------------------------------------------------------
 sub error {
-	my $self = shift;
-	my $line = shift;
-	foreach my $c (@{$self->get($line)}) {
-		return 1 if $c->error;
-	}
-	return;
+  my $self = shift;
+  my $line = shift;
+  foreach my $c (@{ $self->get($line) }) {
+    return 1 if $c->error;
+  }
+  return;
 }
 
-
 #-------------------------------------------------------------------------------
 # Subroutine : branch_coverage()
 # Purpose    : Generate textual representation of branches with/without
@@ -27,45 +26,42 @@ sub error {
 # Notes      :
 #-------------------------------------------------------------------------------
 sub branch_coverage {
-	my $self = shift;
-	my $line = shift;
-	my @txt;
-	foreach my $c (@{$self->get($line)}) {
-		push @txt, ($c->[0][0] ? ' T ' : '---') .
-		           ($c->[0][1] ? ' F ' : '---');
-	}
-	return @txt;
+  my $self = shift;
+  my $line = shift;
+  my @txt;
+  foreach my $c (@{ $self->get($line) }) {
+    push @txt, ($c->[0][0] ? ' T ' : '---') . ($c->[0][1] ? ' F ' : '---');
+  }
+  return @txt;
 }
 
-
 #-------------------------------------------------------------------------------
 # Subroutine : truth_table()
 # Purpose    : Generate truth table(s) for conditional expressions on a line.
 # Notes      :
 #-------------------------------------------------------------------------------
 sub truth_table {
-	my $self = shift;
-	my $line = shift;
-	my $c = $self->get($line);
+  my $self = shift;
+  my $line = shift;
+  my $c    = $self->get($line);
 
-        return if @$c > 16;  # Too big - can't get any useful info anyway.
+  return if @$c > 16;  # Too big - can't get any useful info anyway.
 
-	my @lops;
-	foreach my $c (@$c) {
-		my $op = $c->[1]{type};
-		my @hit = map {defined() && $_ > 0 ? 1 : 0} @{$c->[0]};
-		@hit = reverse @hit if $op =~ /^or_[23]$/;
-		my $t = {
-			tt   => Devel::Cover::Truth_Table->new_primitive($op, @hit),
-			cvg  => $c->[1],
-			expr => join(' ', @{$c->[1]}{qw/left op right/}),
-		};
-		push(@lops, $t);
-	}
-	return map {[$_->{tt}->sort, $_->{expr}]} merge_lineops(@lops);
+  my @lops;
+  foreach my $c (@$c) {
+    my $op  = $c->[1]{type};
+    my @hit = map { defined() && $_ > 0 ? 1 : 0 } @{ $c->[0] };
+    @hit = reverse @hit if $op =~ /^or_[23]$/;
+    my $t = {
+      tt   => Devel::Cover::Truth_Table->new_primitive($op, @hit),
+      cvg  => $c->[1],
+      expr => join(' ', @{ $c->[1] }{qw/left op right/}),
+    };
+    push(@lops, $t);
+  }
+  return map { [ $_->{tt}->sort, $_->{expr} ] } merge_lineops(@lops);
 }
 
-
 #-------------------------------------------------------------------------------
 # Subroutine : merge_lineops()
 # Purpose    : Merge multiple conditional expressions into composite
@@ -73,115 +69,114 @@ sub truth_table {
 # Notes      :
 #-------------------------------------------------------------------------------
 sub merge_lineops {
-	my @ops = @_;
-	my $rotations;
-	while ($#ops > 0) {
-		my $rm;
-		for (1 .. $#ops) {
-			if ($ops[0]{expr} eq $ops[$_]{cvg}{left}) {
-				$ops[$_]{tt}->left_merge($ops[0]{tt});
-				$ops[0] = $ops[$_];
-				$rm = $_; last;
-			}
-			elsif ($ops[0]{expr} eq $ops[$_]{cvg}{right}) {
-				$ops[$_]{tt}->right_merge($ops[0]{tt});
-				$ops[0] = $ops[$_];
-				$rm = $_; last;
-			}
-			elsif ($ops[$_]{expr} eq $ops[0]{cvg}{left}) {
-				$ops[0]{tt}->left_merge($ops[$_]{tt});
-				$rm = $_; last;
-			}
-			elsif ($ops[$_]{expr} eq $ops[0]{cvg}{right}) {
-				$ops[0]{tt}->right_merge($ops[$_]{tt});
-				$rm = $_; last;
-			}
-		}
-		if ($rm) {
-			splice(@ops, $rm, 1);
-			$rotations = 0;
-		}
-		else {
-			# First op didn't merge with anything. Rotate @ops in hopes
-			# of finding something that can be merged.
-			unshift(@ops, pop @ops);
+  my @ops = @_;
+  my $rotations;
+  while ($#ops > 0) {
+    my $rm;
+    for (1 .. $#ops) {
+      if ($ops[0]{expr} eq $ops[$_]{cvg}{left}) {
+        $ops[$_]{tt}->left_merge($ops[0]{tt});
+        $ops[0] = $ops[$_];
+        $rm = $_;
+        last;
+      } elsif ($ops[0]{expr} eq $ops[$_]{cvg}{right}) {
+        $ops[$_]{tt}->right_merge($ops[0]{tt});
+        $ops[0] = $ops[$_];
+        $rm = $_;
+        last;
+      } elsif ($ops[$_]{expr} eq $ops[0]{cvg}{left}) {
+        $ops[0]{tt}->left_merge($ops[$_]{tt});
+        $rm = $_;
+        last;
+      } elsif ($ops[$_]{expr} eq $ops[0]{cvg}{right}) {
+        $ops[0]{tt}->right_merge($ops[$_]{tt});
+        $rm = $_;
+        last;
+      }
+    }
+    if ($rm) {
+      splice(@ops, $rm, 1);
+      $rotations = 0;
+    } else {
+      # First op didn't merge with anything. Rotate @ops in hopes
+      # of finding something that can be merged.
+      unshift(@ops, pop @ops);
 
-			# Hmm... we've come full circle and *still* haven't found
-			# anything to merge. Did the source code have multiple
-			# statements on the same line?
-			last if ($rotations++ > $#ops);
-		}
-	}
-	return @ops;
+      # Hmm... we've come full circle and *still* haven't found
+      # anything to merge. Did the source code have multiple
+      # statements on the same line?
+      last if ($rotations++ > $#ops);
+    }
+  }
+  return @ops;
 }
 
-
 package Devel::Cover::Truth_Table::Row;
 use warnings;
 use strict;
 
 sub new {
-	my $proto = shift;
-	my $class = ref($proto) || $proto;
-	my @args = @_;
-        # use Devel::Cover::Dumper; print Dumper \@args;
-	return bless {
-		inputs    => $args[0],
-		result    => $args[1],
-		covered   => $args[2],
-		criterion => $args[2],
-	}, $class;
+  my $proto = shift;
+  my $class = ref($proto) || $proto;
+  my @args  = @_;
+  # use Devel::Cover::Dumper; print Dumper \@args;
+  return bless {
+    inputs    => $args[0],
+    result    => $args[1],
+    covered   => $args[2],
+    criterion => $args[2],
+  }, $class;
 }
 
 sub inputs {
-	my $self = shift;
-	return @{$self->{inputs}};
+  my $self = shift;
+  return @{ $self->{inputs} };
 }
 
 sub leftcol {
-	my $self = shift;
-	return $self->{inputs}[0];
+  my $self = shift;
+  return $self->{inputs}[0];
 }
 
 sub rightcol {
-	my $self = shift;
-	return $self->{inputs}[-1];
+  my $self = shift;
+  return $self->{inputs}[-1];
 }
 
 sub leftelems {
-	my $self = shift;
-	my $n = $#{$self->{inputs}};
-	return @{$self->{inputs}}[0 .. $n - 1];
+  my $self = shift;
+  my $n    = $#{ $self->{inputs} };
+  return @{ $self->{inputs} }[ 0 .. $n - 1 ];
 }
 
 sub rightelems {
-	my $self = shift;
-	my $n = $#{$self->{inputs}};
-	return @{$self->{inputs}}[1 .. $n];
+  my $self = shift;
+  my $n    = $#{ $self->{inputs} };
+  return @{ $self->{inputs} }[ 1 .. $n ];
 }
 
 sub string {
-	return "@{$_[0]{inputs}}";
+  return "@{$_[0]{inputs}}";
 }
 
 sub result {
-	return $_[0]{result};
+  return $_[0]{result};
 }
 
 sub covered {
-	return $_[0]{covered};
+  return $_[0]{covered};
 }
 
 sub error {
-        return 1;
-        # TODO - sort out how this should really work, or remove this report
-	# return $_[0]{error}[$_[1]];
+  return 1;
+  # TODO - sort out how this should really work, or remove this report
+  # return $_[0]{error}[$_[1]];
 }
 
 package Devel::Cover::Truth_Table;
 use warnings;
 use strict;
-our $VERSION = '1.39'; # VERSION
+our $VERSION = '1.42'; # VERSION
 
 #-------------------------------------------------------------------------------
 # Subroutine : new()
@@ -189,12 +184,11 @@ our $VERSION = '1.39'; # VERSION
 # Notes      : Probably best to keep usage of this internal...
 #-------------------------------------------------------------------------------
 sub new {
-	my $proto = shift;
-	my $class = ref($proto) || $proto;
-	return bless [@_], $class;
+  my $proto = shift;
+  my $class = ref($proto) || $proto;
+  return bless [@_], $class;
 }
 
-
 #-------------------------------------------------------------------------------
 # Subroutine : new_primitive()
 # Purpose    : Create a new Truth_Table object based on one of the built-in
@@ -202,51 +196,48 @@ sub new {
 # Notes      :
 #-------------------------------------------------------------------------------
 sub new_primitive {
-	my ($proto, $type, @coverage) = @_;
+  my ($proto, $type, @coverage) = @_;
 
-	my %table = (
-		and_2 => \&boolean_tt,
-		and_3 => \&and_tt,
-		or_2  => \&boolean_tt,
-		or_3  => \&or_tt,
-		xor_4 => \&xor_tt,
-	);
+  my %table = (
+    and_2 => \&boolean_tt,
+    and_3 => \&and_tt,
+    or_2  => \&boolean_tt,
+    or_3  => \&or_tt,
+    xor_4 => \&xor_tt,
+  );
 
-	return $proto->new($table{$type}->(@coverage));
+  return $proto->new($table{$type}->(@coverage));
 }
 
-
 #-------------------------------------------------------------------------------
 # Subroutine : error()
 # Purpose    : Determine if a table is missing full coverage.
 # Notes      :
 #-------------------------------------------------------------------------------
 sub error {
-    my $self = shift;
-    if (@_) { print "[[[", $self->[shift]->error, "]]]\n"; die }
-    return $self->[shift]->error if @_;
-	foreach (@$self) {
-	    return 1 if $_->error;
-	}
-    return;
+  my $self = shift;
+  if (@_) { print "[[[", $self->[shift]->error, "]]]\n"; die }
+  return $self->[shift]->error if @_;
+  foreach (@$self) {
+    return 1 if $_->error;
+  }
+  return;
 }
 
-
 #-------------------------------------------------------------------------------
 # Subroutine : percentage()
 # Purpose    : Determine the coverage proportion for a truth table.
 # Notes      : Don't care states (X) count as one path, not two.
 #-------------------------------------------------------------------------------
 sub percentage {
-	my $self = shift;
-	my ($p, $c) = (scalar @$self, 0);
-	foreach (@$self) {
-		$c++ if $_->covered;
-	}
-	return ($c == $p) ? 100 : 100 * $c / $p;
+  my $self = shift;
+  my ($p, $c) = (scalar @$self, 0);
+  foreach (@$self) {
+    $c++ if $_->covered;
+  }
+  return ($c == $p) ? 100 : 100 * $c / $p;
 }
 
-
 # Basic truth table constructors
 # Construct a new truth table for 'A <op> B' coverage listing
 # primitives. More complicated tables are constructed by merging
@@ -264,26 +255,36 @@ sub percentage {
 #       1 |  1 |    1     |    1
 #
 sub and_tt {
-	return(Devel::Cover::Truth_Table::Row->new([0, 'X'], 0, shift),
-           Devel::Cover::Truth_Table::Row->new([1,  0 ], 0, shift),
-           Devel::Cover::Truth_Table::Row->new([1,  1 ], 1, shift));
-}
-sub or_tt {
-	return(Devel::Cover::Truth_Table::Row->new([0,  0 ], 0, shift),
-	       Devel::Cover::Truth_Table::Row->new([0,  1 ], 1, shift),
-	       Devel::Cover::Truth_Table::Row->new([1, 'X'], 1, shift));
-}
-sub xor_tt {
-	return(Devel::Cover::Truth_Table::Row->new([0, 0], 0, shift),
-	       Devel::Cover::Truth_Table::Row->new([0, 1], 1, shift),
-	       Devel::Cover::Truth_Table::Row->new([1, 0], 1, shift),
-	       Devel::Cover::Truth_Table::Row->new([1, 1], 0, shift));
-}
-sub boolean_tt {
-	return(Devel::Cover::Truth_Table::Row->new([0], 0, shift),
-	       Devel::Cover::Truth_Table::Row->new([1], 1, shift));
+  return (
+    Devel::Cover::Truth_Table::Row->new([ 0, 'X' ], 0, shift),
+    Devel::Cover::Truth_Table::Row->new([ 1, 0 ],   0, shift),
+    Devel::Cover::Truth_Table::Row->new([ 1, 1 ],   1, shift)
+  );
 }
 
+sub or_tt {
+  return (
+    Devel::Cover::Truth_Table::Row->new([ 0, 0 ],   0, shift),
+    Devel::Cover::Truth_Table::Row->new([ 0, 1 ],   1, shift),
+    Devel::Cover::Truth_Table::Row->new([ 1, 'X' ], 1, shift)
+  );
+}
+
+sub xor_tt {
+  return (
+    Devel::Cover::Truth_Table::Row->new([ 0, 0 ], 0, shift),
+    Devel::Cover::Truth_Table::Row->new([ 0, 1 ], 1, shift),
+    Devel::Cover::Truth_Table::Row->new([ 1, 0 ], 1, shift),
+    Devel::Cover::Truth_Table::Row->new([ 1, 1 ], 0, shift)
+  );
+}
+
+sub boolean_tt {
+  return (
+    Devel::Cover::Truth_Table::Row->new([0], 0, shift),
+    Devel::Cover::Truth_Table::Row->new([1], 1, shift)
+  );
+}
 
 #-------------------------------------------------------------------------------
 # Subroutine : sort()
@@ -291,35 +292,35 @@ sub boolean_tt {
 # Notes      :
 #-------------------------------------------------------------------------------
 sub sort {
-	my $self = shift;
-	@$self = sort {$a->string cmp $b->string} @$self;
-	return $self;
+  my $self = shift;
+  @$self = sort { $a->string cmp $b->string } @$self;
+  return $self;
 }
 
-
 #sub rows {return @{$_[0]}}
 
-
 #-------------------------------------------------------------------------------
 # Subroutine : text()
 # Purpose    : Formatted text representation of a truth table
 # Notes      :
 #-------------------------------------------------------------------------------
 sub text {
-	my $self = shift;
-	my $h = 'A';
-	my @h = map {$h++} ($self->[0]->inputs);
-	my $hdr = "@h |exp|hit";
-	my @text;
-	push @text, $hdr, '-' x length($hdr);
-	foreach (@$self) {
-		push @text, sprintf("%s | %s |%s", $_->string(),
-			$_->result(), $_->covered() ? '+++' : '---');
-	}
-	push @text, '-' x length($hdr);
-	return @text;
-}
 
+  my $self = shift;
+  my $h    = 'A';
+  my @h    = map { $h++ } ($self->[0]->inputs);
+  my $hdr  = "@h |exp|hit";
+  my @text;
+
+  push @text, $hdr, '-' x length($hdr);
+  foreach (@$self) {
+    push @text,
+      sprintf("%s | %s |%s",
+        $_->string(), $_->result(), $_->covered() ? '+++' : '---');
+  }
+  push @text, '-' x length($hdr);
+  return @text;
+}
 
 #-------------------------------------------------------------------------------
 # Subroutine : html()
@@ -327,28 +328,27 @@ sub text {
 # Notes      :
 #-------------------------------------------------------------------------------
 sub html {
-	my $self  = shift;
-	my @class = (shift || 'uncovered', shift || 'covered');
-	my $html  = "<table><tr>";
-	my $h     = 'A';
-	for ($self->[0]->inputs) {
-		$html .= "<th>$h</th>";
-		$h++;
-	}
-	$html .= "<th>dec</th></tr>";
+  my $self  = shift;
+  my @class = (shift || 'uncovered', shift || 'covered');
+  my $html  = "<table><tr>";
+  my $h     = 'A';
+  for ($self->[0]->inputs) {
+    $html .= "<th>$h</th>";
+    $h++;
+  }
+  $html .= "<th>dec</th></tr>";
 
-        my $c = 0;
-	foreach (@$self) {
-		my $class = $class[!$_->error($c++) || $_->covered];
-		$html .= qq'<tr align="center"><td class="$class">';
-		$html .= join(qq'</td><td class="$class">', $_->inputs, $_->result);
-		$html .= "</td></tr>";
-	}
-	$html .= "</table>";
-	return $html;
+  my $c = 0;
+  foreach (@$self) {
+    my $class = $class[ !$_->error($c++) || $_->covered ];
+    $html .= qq'<tr align="center"><td class="$class">';
+    $html .= join(qq'</td><td class="$class">', $_->inputs, $_->result);
+    $html .= "</td></tr>";
+  }
+  $html .= "</table>";
+  return $html;
 }
 
-
 # Truth table merge routines:
 # Combine simple truth tables into more complicated ones.
 #
@@ -407,30 +407,40 @@ sub html {
 # Notes      :
 #-------------------------------------------------------------------------------
 sub right_merge {
-	my ($tt1, $tt2) = @_;
+  my ($tt1, $tt2) = @_;
 
-	# find the rows of tt2 that have a result of false/true
-	my @merge = ([grep {! $_->result} @$tt2], [grep {$_->result} @$tt2]);
-	# if the rightmost column of tt1 is 'X', we don't care what the
-	# input from tt2 was
-	my @dontcare = map {'X'} $tt2->[0]->inputs;
+  # find the rows of tt2 that have a result of false/true
+  my @merge = ([ grep { !$_->result } @$tt2 ], [ grep { $_->result } @$tt2 ]);
+  # if the rightmost column of tt1 is 'X', we don't care what the
+  # input from tt2 was
+  my @dontcare = map { 'X' } $tt2->[0]->inputs;
 
-	my @tt;
-	foreach my $row1 (@$tt1) {
-		if ($row1->rightcol eq 'X') {
-			push(@tt, Devel::Cover::Truth_Table::Row->new([$row1->leftelems, @dontcare],
-				$row1->result, $row1->covered));
-		}
-		else {
-			# expand value from tt1 with rows from tt2 that result in
-			# that value
-			foreach my $row2 (@{$merge[$row1->rightcol]}) {
-				push(@tt, Devel::Cover::Truth_Table::Row->new([$row1->leftelems, $row2->inputs],
-					$row1->result, $row1->covered && $row2->covered));
-			}
-		}
-	}
-	$_[0] = $tt2->new(@tt);
+  my @tt;
+  foreach my $row1 (@$tt1) {
+    if ($row1->rightcol eq 'X') {
+      push(
+        @tt,
+        Devel::Cover::Truth_Table::Row->new(
+          [ $row1->leftelems, @dontcare ],
+          $row1->result, $row1->covered
+        )
+      );
+    } else {
+      # expand value from tt1 with rows from tt2 that result in
+      # that value
+      foreach my $row2 (@{ $merge[ $row1->rightcol ] }) {
+        push(
+          @tt,
+          Devel::Cover::Truth_Table::Row->new(
+            [ $row1->leftelems, $row2->inputs ],
+            $row1->result,
+            $row1->covered && $row2->covered
+          )
+        );
+      }
+    }
+  }
+  $_[0] = $tt2->new(@tt);
 }
 
 #-------------------------------------------------------------------------------
@@ -439,23 +449,28 @@ sub right_merge {
 # Notes      :
 #-------------------------------------------------------------------------------
 sub left_merge {
-	my ($tt1, $tt2) = @_;
+  my ($tt1, $tt2) = @_;
 
-	# find the rows of tt2 that have a result of false/true
-	my @merge = ([grep {! $_->result} @$tt2], [grep {$_->result} @$tt2]);
+  # find the rows of tt2 that have a result of false/true
+  my @merge = ([ grep { !$_->result } @$tt2 ], [ grep { $_->result } @$tt2 ]);
 
-	my @tt;
-	foreach my $row1 (@$tt1) {
-		my $rightmatters  = grep {$_ ne 'X'} $row1->rightelems;
-		foreach my $row2 (@{$merge[$row1->leftcol]}) {
-			# expand value from tt1 with rows from tt2 that result in
-			# that value
-			push(@tt, Devel::Cover::Truth_Table::Row->new([$row2->inputs, $row1->rightelems],
-				$row1->result,
-				($rightmatters) ? $row1->covered && $row2->covered : $row2->covered));
-		}
-	}
-	$_[0] = $tt2->new(@tt);
+  my @tt;
+  foreach my $row1 (@$tt1) {
+    my $rightmatters = grep { $_ ne 'X' } $row1->rightelems;
+    foreach my $row2 (@{ $merge[ $row1->leftcol ] }) {
+      # expand value from tt1 with rows from tt2 that result in
+      # that value
+      push(
+        @tt,
+        Devel::Cover::Truth_Table::Row->new(
+          [ $row2->inputs, $row1->rightelems ],
+          $row1->result,
+          ($rightmatters) ? $row1->covered && $row2->covered : $row2->covered
+        )
+      );
+    }
+  }
+  $_[0] = $tt2->new(@tt);
 }
 
 1;
@@ -468,7 +483,7 @@ Devel::Cover::Truth_Table - Truth tables for coverage objects.
 
 =head1 VERSION
 
-version 1.39
+version 1.42
 
 =head1 SYNOPSIS
 
